@@ -161,7 +161,7 @@ sub _load_fill_blank_data ($self) {
 
                 foreach my $k (keys $fill_blanks{$path}->%*) {
                     die "Error in file $file: Unexpected key '$k' in path '$path'\n"
-                        unless $k =~/^(comment|skip|(override-)?(license|copyright))$/;
+                        unless $k =~/^((forwarded-)?comment|skip|(override-)?(license|copyright))$/;
                 }
             }
         }
@@ -286,7 +286,7 @@ sub squash_copyright_years ($self) {
         grep {$_->copyright}
         $self->all_grants
     ) {
-        my $key = $grant->lic_owner_hash;
+        my $key = $grant->lic_comment_owner_hash;
         $hash_year_by_same_owner_license{$key} //= [];
         push $hash_year_by_same_owner_license{$key}->@*, $grant;
     }
@@ -551,8 +551,8 @@ sub __apply_fill_blank ($self, $file, $grant) {
         $grant->license( $fill_blank->{license});
     }
 
-    if ( not $grant->comment and $fill_blank->{comment} ) {
-        $grant->comment( $fill_blank->{comment});
+    if ( not $grant->comment and $fill_blank->{'forwarded-comment'} ) {
+        $grant->comment( $fill_blank->{'forwarded-comment'});
     }
 
     return ;
